import * as cdk from 'aws-cdk-lib';
import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * Configuration options for DAG storage.
 */
export interface DagStorageConfigOptions {
    /** The S3 path where the resource is stored. */
    readonly s3Path: string;
    /** Optional local path for the resource. */
    readonly localPath?: string;
    /** Deployment options for DAG storage. */
    readonly deployOptions?: DagStorageDeployOptions;
}
export interface DagStorageConfigOptionsWithS3ObjectVersion extends DagStorageConfigOptions {
    /** S3 object version identifier. */
    readonly s3ObjectVersion?: string;
}
/**
 * Options for deploying files to the DAG storage bucket.
 */
export interface DagStorageDeployOptions {
    /** Patterns to exclude from deployment. */
    readonly exclude?: string[];
    /** Whether to retain files upon stack deletion. */
    readonly retainOnDelete?: boolean;
    /** Whether to remove outdated file versions. */
    readonly prune?: boolean;
}
/**
 * Properties for configuring the DAG storage bucket.
 */
export interface DagStorageProps {
    /** Custom bucket name (optional). */
    readonly bucketName?: string;
    /** Enable versioning for the bucket. */
    readonly versioned?: boolean;
    /** Lifecycle rule for expiring non-current object versions. */
    readonly noncurrentVersionExpiration?: cdk.Duration;
    /** Bucket removal policy. */
    readonly removalPolicy?: cdk.RemovalPolicy;
    /** Configuration for DAG storage. */
    readonly dagsConfig?: DagStorageConfigOptions;
    /** Configuration for plugins storage. */
    readonly pluginsConfig?: DagStorageConfigOptionsWithS3ObjectVersion;
    /** Configuration for requirements storage. */
    readonly requirementsConfig?: DagStorageConfigOptionsWithS3ObjectVersion;
    /** Configuration for startup script storage. */
    readonly startupScriptConfig?: DagStorageConfigOptionsWithS3ObjectVersion;
}
/**
 * Represents an S3 storage solution for MWAA DAGs and dependencies.
 */
export declare class DagStorage extends Construct {
    /** The S3 bucket storing DAGs, plugins, requirements, and startup scripts. */
    readonly bucket: s3.Bucket;
    /** S3 path for DAGs. */
    readonly dagS3Path?: string;
    /** Plugin storage configuration. */
    readonly pluginsConfig?: DagStorageConfigOptionsWithS3ObjectVersion;
    /** Requirements storage configuration. */
    readonly requirementsConfig?: DagStorageConfigOptionsWithS3ObjectVersion;
    /** Startup script storage configuration. */
    readonly startupScriptConfig?: DagStorageConfigOptionsWithS3ObjectVersion;
    constructor(scope: Construct, id: string, props: DagStorageProps);
    private deployConfig;
}
